@@ -1,4 +1,5 @@
-"""Problem A in paper "Outer approximation algorithms for separable nonconvex mixed-integer nonlinear programs"
+# -*- coding: utf-8 -*-
+"""Problem A in paper 'Outer approximation algorithms for separable nonconvex mixed-integer nonlinear programs'
 
 Ref:
 Kesavan P, Allgor R J, Gatzke E P, et al. Outer approximation algorithms for separable nonconvex mixed-integer nonlinear programs[J]. Mathematical Programming, 2004, 100(3): 517-535.
@@ -33,3 +34,4 @@ class Nonconvex1(ConcreteModel):
         m.c4 = Constraint(expr=m.x1 + m.y1 <= 1.6)
         m.c5 = Constraint(expr=1.333 * m.x2 + m.y2 <= 3)
         m.c6 = Constraint(expr=-m.y1 - m.y2 + m.y3 <= 0)
+        m.optimal_value = 7.667
